package com.fyber.mediation;

import android.app.Activity;
import com.fyber.mediation.adcolony.AdColonyMediationAdapter;
import com.fyber.mediation.applovin.AppLovinMediationAdapter;
import com.fyber.mediation.unityads.UnityAdsMediationAdapter;
import com.fyber.utils.FyberLogger;
import java.lang.Object;
import java.lang.String;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

public final class MediationAdapterStarter {
  private static final String TAG = "MediationAdapterStarter";

  private static void startApplifier(final Activity activity, final Map<String, Object> configs, final Map<String, MediationAdapter> map) {
    try {
      MediationAdapter adapter = new UnityAdsMediationAdapter();
      FyberLogger.d(TAG, "Starting adapter Applifier with version 1.5.2-r2");
      if (adapter.startAdapter(activity, configs)) {
        FyberLogger.d(TAG, "Adapter Applifier with version 1.5.2-r2 was started successfully");
        map.put("applifier", adapter);
      } else {
        FyberLogger.d(TAG, "Adapter Applifier with version 1.5.2-r2 was not started successfully");
      }
    } catch (Exception e) {
      FyberLogger.e(TAG, "Exception occurred while loading adapter Applifier with version 1.5.2-r2", e);
    }
  }

  private static void startAppLovin(final Activity activity, final Map<String, Object> configs, final Map<String, MediationAdapter> map) {
    try {
      MediationAdapter adapter = new AppLovinMediationAdapter();
      FyberLogger.d(TAG, "Starting adapter AppLovin with version 6.1.4-r1");
      if (adapter.startAdapter(activity, configs)) {
        FyberLogger.d(TAG, "Adapter AppLovin with version 6.1.4-r1 was started successfully");
        map.put("applovin", adapter);
      } else {
        FyberLogger.d(TAG, "Adapter AppLovin with version 6.1.4-r1 was not started successfully");
      }
    } catch (Exception e) {
      FyberLogger.e(TAG, "Exception occurred while loading adapter AppLovin with version 6.1.4-r1", e);
    }
  }

  private static void startAdColony(final Activity activity, final Map<String, Object> configs, final Map<String, MediationAdapter> map) {
    try {
      MediationAdapter adapter = new AdColonyMediationAdapter();
      FyberLogger.d(TAG, "Starting adapter AdColony with version 2.3.0-r3");
      if (adapter.startAdapter(activity, configs)) {
        FyberLogger.d(TAG, "Adapter AdColony with version 2.3.0-r3 was started successfully");
        map.put("adcolony", adapter);
      } else {
        FyberLogger.d(TAG, "Adapter AdColony with version 2.3.0-r3 was not started successfully");
      }
    } catch (Exception e) {
      FyberLogger.e(TAG, "Exception occurred while loading adapter AdColony with version 2.3.0-r3", e);
    }
  }

  public static Map<String, MediationAdapter> startAdapters(final Activity activity, final Map<String, Map<String, Object>> configs) {
    Map<String, MediationAdapter> map = new HashMap<>();
    startApplifier(activity, getConfigs(configs, "Applifier"), map);
    startAppLovin(activity, getConfigs(configs, "AppLovin"), map);
    startAdColony(activity, getConfigs(configs, "AdColony"), map);
    return map;
  }

  public static int getAdaptersCount() {
    return 3;
  }

  private static Map<String, Object> getConfigs(Map<String, Map<String, Object>> configs, String adapter) {
    Map<String, Object> config = configs.get(adapter.toLowerCase());
    if (config == null) {
      config = Collections.emptyMap();
    }
    return config;
  }
}
